PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Clone.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
Clone.hpp
1
2#ifndef GYM_PCB_CLONE_H
3#define GYM_PCB_CLONE_H
4
5#include <map>
6
7class PCBoard;
8class Component;
9class Pin;
10class Net;
11class Connection;
12
16 class CloneEnv
17{
18public:
19 CloneEnv(PCBoard &pcb) : origin(pcb) { }
20 const PCBoard &origin;
21 std::map<const Component *, Component *> C;
22 std::map<const Pin *, Pin *> P;
23 std::map<const std::vector<Pin *> *, std::vector<Pin *> *> PK;
24 std::map<const Net *, Net *> N;
25 std::map<const Connection *, Connection *> X;
26 PCBoard *target{0};
27};
28
29#endif // GYM_PCB_CLONE_H
Component
Definition Component.hpp:18
Connection
Definition Connection.hpp:17
Net
Definition Net.hpp:19
PCBoard
Definition PCBoard.hpp:36
Pin
Definition Pin.hpp:18